package com.jiuqi.office.excel;

import com.jiuqi.grid.CellField;
import com.jiuqi.grid.CurrencyCellProperty;
import com.jiuqi.grid.GridCell;
import com.jiuqi.grid.GridData;
import com.jiuqi.grid.GridFieldList;
import com.jiuqi.grid.NumberCellProperty;
import java.text.NumberFormat;
import java.util.ArrayList;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.apache.poi.hssf.usermodel.HSSFRichTextString;
import org.apache.poi.hssf.usermodel.HSSFSheet;
import org.apache.poi.hssf.usermodel.HSSFWorkbook;
import org.apache.poi.hssf.util.CellRangeAddress;
import org.apache.poi.hssf.util.HSSFColor;
import org.apache.poi.ss.usermodel.Cell;
import org.apache.poi.ss.usermodel.CellStyle;
import org.apache.poi.ss.usermodel.Font;
import org.apache.poi.ss.usermodel.RichTextString;
import org.apache.poi.ss.usermodel.Row;
import org.apache.poi.ss.usermodel.Sheet;
import org.apache.poi.ss.usermodel.Workbook;
import org.apache.poi.xssf.streaming.SXSSFWorkbook;
import org.apache.poi.xssf.usermodel.XSSFRichTextString;
import org.apache.poi.xssf.usermodel.XSSFWorkbook;

/* loaded from: com_jiuqi_office_excel.jar:com/jiuqi/office/excel/WorksheetWriter.class */
public final class WorksheetWriter {
    private Workbook workBook;
    private Sheet sheet;
    private GridData gridData;
    private String title;
    private boolean autoAdjust;
    private boolean addTitle;
    private Font titleFont;
    private HashMap cellStyleHashMap;
    private int transparentColor;
    private boolean doNotCheckNumberIsNull;
    private Map HSSFFontMap;
    private List sheets = new ArrayList();
    private static int MAX_COLUMN = 255;
    private String preSheetName;

    public WorksheetWriter(HSSFWorkbook workBook, HSSFSheet sheet, GridData gridData, HashMap cellStyleHashMap) {
        this.workBook = workBook;
        this.sheet = sheet;
        this.sheets.add(sheet);
        this.gridData = gridData;
        this.cellStyleHashMap = cellStyleHashMap;
        this.HSSFFontMap = new HashMap();
        this.transparentColor = -16777201;
    }

    public WorksheetWriter(Workbook workBook, Sheet sheet, GridData gridData, HashMap cellStyleHashMap) {
        this.workBook = workBook;
        this.sheet = sheet;
        this.sheets.add(sheet);
        this.gridData = gridData;
        this.cellStyleHashMap = cellStyleHashMap;
        this.HSSFFontMap = new HashMap();
        this.transparentColor = -16777201;
    }

    public String getPreSheetName() {
        return this.preSheetName;
    }

    public void setPreSheetName(String preSheetName) {
        this.preSheetName = preSheetName;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    private void setDefaultTitleFont() {
        this.titleFont = this.workBook.createFont();
        this.titleFont.setFontName(ExportConsts.TITLE_FONTNAME);
        this.titleFont.setBoldweight((short) 700);
        this.titleFont.setFontHeightInPoints((short) 12);
    }

    public void setAutoAdjust(boolean autoAdjust) {
        this.autoAdjust = autoAdjust;
    }

    public void setAddTitle(boolean addTitle) {
        this.addTitle = addTitle;
    }

    public void setTransparentColor(int transparentColor) {
        this.transparentColor = transparentColor;
    }

    public boolean isDoNotCheckNumberIsNull() {
        return this.doNotCheckNumberIsNull;
    }

    public void setDoNotCheckNumberIsNull(boolean doNotCheckNumberIsNull) {
        this.doNotCheckNumberIsNull = doNotCheckNumberIsNull;
    }

    public void writeWorkSheet() {
        addSheets();
        addTitle();
        writeContent();
        adjustHW();
        mergeCells();
        hideRowCol();
    }

    private Sheet getSheet(int index) {
        return (Sheet) this.sheets.get(index);
    }

    private int getSheetIndex(int col) {
        return col / MAX_COLUMN;
    }

    private int getCol(int col) {
        return col % MAX_COLUMN;
    }

    private void addSheets() {
        if (this.gridData.getColCount() > MAX_COLUMN) {
            int extraSheetsNum = (((this.gridData.getColCount() + MAX_COLUMN) - 1) / MAX_COLUMN) - 1;
            for (int i = 0; i < extraSheetsNum; i++) {
                this.sheets.add(this.workBook.createSheet(String.valueOf(this.preSheetName) + (i + 1)));
            }
        }
    }

    private void addTitle() {
        if (this.addTitle) {
            setDefaultTitleFont();
            RichTextString richText = getRichTextString(this.title, this.workBook);
            for (int i = 0; i < this.sheets.size(); i++) {
                Cell cell = getSheet(i).createRow(0).createCell(0);
                if (richText != null) {
                    cell.setCellValue(richText);
                }
                CellStyle titleCellStyle = this.workBook.createCellStyle();
                titleCellStyle.setAlignment((short) 2);
                titleCellStyle.setFont(this.titleFont);
                cell.setCellStyle(titleCellStyle);
                getSheet(i).addMergedRegion(new CellRangeAddress(0, 0, 0, Math.min(this.gridData.getColCount() - 2, MAX_COLUMN)));
            }
        }
    }

    private void writeContent() {
        if (this.gridData == null) {
            throw new NullPointerException("表格数据不能为空");
        }
        int rowCount = this.gridData.getRowCount();
        int colCount = this.gridData.getColCount();
        for (int row = 1; row < rowCount; row++) {
            for (int col = 1; col < colCount; col++) {
                GridCell gridCell = this.gridData.getCell(col, row);
                writeCell(gridCell);
            }
        }
    }

    private void writeCell(GridCell gridCell) {
        Row row;
        int rowNum = gridCell.getRowNum() - 1;
        int colNum = gridCell.getColNum() - 1;
        if (this.addTitle) {
            rowNum++;
        }
        if (getSheet(getSheetIndex(colNum)).getRow(rowNum) == null) {
            row = getSheet(getSheetIndex(colNum)).createRow(rowNum);
        } else {
            row = getSheet(getSheetIndex(colNum)).getRow(rowNum);
        }
        Row row2 = row;
        Cell cell = row2.createCell(getCol(colNum));
        try {
            CellStyle cellStyle = buildCellStyle(gridCell);
            cell.setCellStyle(cellStyle);
            switch (gridCell.getDataType()) {
                case 0:
                case 1:
                case 4:
                    String strValue = gridCell.getCellData();
                    RichTextString richTextString = getRichTextString(strValue, this.workBook);
                    if (richTextString != null) {
                        cell.setCellValue(richTextString);
                        return;
                    }
                    return;
                case SimpleExportor.EXPORT_MODE_2007_LATER_SUPER /* 2 */:
                    String cellData = gridCell.getCellData();
                    if (cellData != null && !cellData.equals("")) {
                        double value = gridCell.getFloat();
                        cell.setCellValue(value);
                        if (gridCell.getShowText().endsWith("‰")) {
                            NumberCellProperty ncp = new NumberCellProperty(gridCell);
                            String decimalStr = String.valueOf(buildDecimal(ncp, -3)) + "‰";
                            NumberFormat numf = NumberFormat.getInstance();
                            numf.setGroupingUsed(true);
                            RichTextString richTextString2 = getRichTextString(numf.format(value * 1000.0d), this.workBook);
                            if (richTextString2 == null) {
                                cell.setCellValue(richTextString2 + decimalStr);
                                return;
                            } else {
                                cell.setCellValue(decimalStr);
                                return;
                            }
                        }
                        return;
                    }
                    return;
                case 3:
                    String cellData2 = gridCell.getCellData();
                    if (cellData2 != null && !cellData2.equals("")) {
                        if ("|".equals(cellData2)) {
                            String value2 = gridCell.getShowText();
                            RichTextString richTextString3 = getRichTextString(value2, this.workBook);
                            if (richTextString3 != null) {
                                cell.setCellValue(richTextString3);
                                return;
                            }
                            return;
                        }
                        double value3 = Double.parseDouble(cellData2);
                        cell.setCellValue(value3);
                        return;
                    }
                    return;
                case 5:
                    Date date = gridCell.getDateTime();
                    if (date != null) {
                        cell.setCellValue(date);
                        return;
                    }
                    return;
                case 9:
                    String linkInfoStr = gridCell.getCellData();
                    if (linkInfoStr != null && !"".equals(linkInfoStr)) {
                        String[] info = GridCell.parserLinkInformation(linkInfoStr);
                        RichTextString hssfStr = getRichTextString(info[0], this.workBook);
                        if (hssfStr != null) {
                            cell.setCellValue(hssfStr);
                            break;
                        } else {
                            return;
                        }
                    } else {
                        return;
                    }
                    break;
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    private String makeCurFotmat(CurrencyCellProperty curCellProperty) {
        String str;
        String str2;
        String str3;
        String str4;
        String str5;
        String colorStr = "";
        String currencyFormat = String.valueOf(ExportConsts.FORMAT_CURRENCY) + buildDecimal(curCellProperty, 0);
        int idx = curCellProperty.getUnitIndex();
        if (curCellProperty.getWarningNegative()) {
            colorStr = "[Red]";
        }
        boolean isBracketNegative = curCellProperty.getBracketNegative();
        switch (curCellProperty.getUnitShowType()) {
            case 0:
                String signStr = CurrencyCellProperty.CURRENCY_UNIT_SIGNS[idx];
                if (signStr.length() == 1) {
                    if (isBracketNegative) {
                        str5 = String.valueOf(signStr) + currencyFormat + ";" + colorStr + signStr + "(" + currencyFormat + ")";
                    } else {
                        str5 = String.valueOf(signStr) + currencyFormat + ";" + colorStr + signStr + "-" + currencyFormat;
                    }
                    currencyFormat = str5;
                    break;
                } else if (signStr.length() > 1) {
                    if (isBracketNegative) {
                        str4 = "[$" + signStr + "]" + currencyFormat + ";" + colorStr + "[$" + signStr + "](" + currencyFormat + ")";
                    } else {
                        str4 = "[$" + signStr + "]" + currencyFormat + ";" + colorStr + "[$" + signStr + "]-" + currencyFormat;
                    }
                    currencyFormat = str4;
                    break;
                }
                break;
            case 1:
                String nameStr = CurrencyCellProperty.CURRENCY_UNIT_NAMES[idx];
                if (isBracketNegative) {
                    str3 = "[$" + nameStr + "] " + currencyFormat + ";" + colorStr + "[$" + nameStr + "] (" + currencyFormat + ")";
                } else {
                    str3 = "[$" + nameStr + "] " + currencyFormat + ";" + colorStr + "[$" + nameStr + "] -" + currencyFormat;
                }
                currencyFormat = str3;
                break;
            case SimpleExportor.EXPORT_MODE_2007_LATER_SUPER /* 2 */:
                String nameStr2 = CurrencyCellProperty.CURRENCY_UNIT_NAMES[idx];
                if (isBracketNegative) {
                    str2 = String.valueOf(currencyFormat) + " [$" + nameStr2 + "];" + colorStr + "(" + currencyFormat + ") [$" + nameStr2 + "]";
                } else {
                    str2 = String.valueOf(currencyFormat) + " [$" + nameStr2 + "];" + colorStr + "-" + currencyFormat + " [$" + nameStr2 + "]";
                }
                currencyFormat = str2;
                break;
            case 3:
                String titleStr = CurrencyCellProperty.CURRENCY_UNIT_TITLES[idx];
                if (isBracketNegative) {
                    str = "[$" + titleStr + "] " + currencyFormat + ";" + colorStr + "[$" + titleStr + "] (" + currencyFormat + ")";
                } else {
                    str = "[$" + titleStr + "] " + currencyFormat + ";" + colorStr + "[$" + titleStr + "] -" + currencyFormat;
                }
                currencyFormat = str;
                break;
        }
        return currencyFormat;
    }

    private String buildDecimal(NumberCellProperty numberCellProperty, int offset) {
        int decimalCount = numberCellProperty.getDecimal() + offset;
        if (decimalCount > 0) {
            String decimal = ".";
            for (int i = 0; i < decimalCount; i++) {
                decimal = String.valueOf(decimal) + "0";
            }
            return decimal;
        }
        return "";
    }

    private Font getCellFont(GridCell gridCell) {
        String fontKey = getCellFontKey(gridCell);
        Font font = (Font) this.HSSFFontMap.get(fontKey);
        if (font == null) {
            font = this.workBook.createFont();
            this.HSSFFontMap.put(fontKey, font);
            if (gridCell.getFontBold()) {
                font.setBoldweight((short) 700);
            }
            if (HSSFHelper.getApproximateTextColor(gridCell.getFontColor()) != null) {
            }
            font.setFontHeight((short) gridCell.getFontHeight());
            font.setItalic(gridCell.getFontItalic());
            font.setFontName(gridCell.getFontName());
            font.setFontHeightInPoints((short) gridCell.getFontSize());
            font.setStrikeout(gridCell.getFontStrikeOut());
            if (gridCell.getFontUnderLine()) {
                font.setUnderline((byte) 1);
            }
        }
        return font;
    }

    private String getCellFontKey(GridCell cell) {
        StringBuffer key = new StringBuffer();
        key.append(cell.getFontName());
        key.append(cell.getFontSize());
        key.append(cell.getFontColor());
        key.append(cell.getFontHeight());
        key.append(cell.getFontBold());
        key.append(cell.getFontItalic());
        key.append(cell.getFontStrikeOut());
        key.append(cell.getFontUnderLine());
        return key.toString();
    }

    private CellStyle buildCellStyle(GridCell gridCell) {
        HSSFColor backColor;
        String formatStr;
        String numStr;
        String formatStr2;
        String formatStr3;
        CellStyle cellStyle = (CellStyle) this.cellStyleHashMap.get(gridCell);
        if (cellStyle != null) {
            return cellStyle;
        }
        GridCell tempGridCell = this.gridData.getCellEx(gridCell.getColNum(), gridCell.getRowNum());
        CellStyle cellStyle2 = this.workBook.createCellStyle();
        short backColorIdx = 9;
        if (tempGridCell.getSilverHead()) {
            backColorIdx = 22;
        } else if (tempGridCell.getBackStyle() != 0 && (backColor = HSSFHelper.getApproximateColor(tempGridCell.getBackColor())) != null) {
            backColorIdx = backColor.getIndex();
        }
        cellStyle2.setFillForegroundColor(backColorIdx);
        if (backColorIdx != 58) {
            cellStyle2.setFillPattern((short) 1);
        }
        short leftBorder = transBorderStyle(tempGridCell.getLEdgeStyle());
        short topBorder = transBorderStyle(tempGridCell.getTEdgeStyle());
        short rightBorder = transBorderStyle(tempGridCell.getREdgeStyle());
        short bottomBorder = transBorderStyle(tempGridCell.getBEdgeStyle());
        HSSFColor leftBorderColor = HSSFHelper.getApproximateEdgeColor(tempGridCell.getLEdgeColor());
        HSSFColor topBorderColor = HSSFHelper.getApproximateEdgeColor(tempGridCell.getTEdgeColor());
        HSSFColor righttBorderColor = HSSFHelper.getApproximateEdgeColor(tempGridCell.getREdgeColor());
        HSSFColor bottomBorderColor = HSSFHelper.getApproximateEdgeColor(tempGridCell.getBEdgeColor());
        cellStyle2.setBorderLeft(leftBorder);
        cellStyle2.setBorderTop(topBorder);
        cellStyle2.setBorderRight(rightBorder);
        cellStyle2.setBorderBottom(bottomBorder);
        if (leftBorderColor != null) {
            cellStyle2.setLeftBorderColor(leftBorderColor.getIndex());
        }
        if (topBorderColor != null) {
            cellStyle2.setTopBorderColor(topBorderColor.getIndex());
        }
        if (righttBorderColor != null) {
            cellStyle2.setRightBorderColor(righttBorderColor.getIndex());
        }
        if (bottomBorderColor != null) {
            cellStyle2.setBottomBorderColor(bottomBorderColor.getIndex());
        }
        short horzAlign = transCellAlign(tempGridCell.getHorzAlign(), true);
        short vertAlign = transCellAlign(tempGridCell.getVertAlign(), false);
        cellStyle2.setAlignment(horzAlign);
        cellStyle2.setVerticalAlignment(vertAlign);
        cellStyle2.setWrapText(tempGridCell.getWrapLine());
        cellStyle2.setIndention((short) tempGridCell.getIndent());
        Font font = getCellFont(tempGridCell);
        cellStyle2.setFont(font);
        if (tempGridCell.getDataType() == 1) {
            short formatIndex = this.workBook.createDataFormat().getFormat(ExportConsts.FORMAT_TEXT);
            cellStyle2.setDataFormat(formatIndex);
        }
        if (tempGridCell.getDataType() == 2 && (this.doNotCheckNumberIsNull || tempGridCell.getShowText() != null)) {
            if (tempGridCell.getShowText() == null) {
                NumberCellProperty ncp = new NumberCellProperty(tempGridCell);
                if (ncp.getThoundsMark()) {
                    formatStr3 = ExportConsts.FORMAT_CURRENCY + buildDecimal(ncp, 0);
                } else {
                    formatStr3 = String.valueOf("0") + buildDecimal(ncp, 0);
                }
                short formatIndex2 = this.workBook.createDataFormat().getFormat(String.valueOf(formatStr3) + " ");
                cellStyle2.setDataFormat(formatIndex2);
            } else if (tempGridCell.getShowText().endsWith("%")) {
                String formatStr4 = "0" + buildDecimal(new NumberCellProperty(tempGridCell), -2) + "%";
                short formatIndex3 = this.workBook.createDataFormat().getFormat(formatStr4);
                cellStyle2.setDataFormat(formatIndex3);
            } else if (tempGridCell.getShowText().endsWith("‰")) {
                NumberCellProperty ncp2 = new NumberCellProperty(gridCell);
                String colorStr = "";
                if (ncp2.getThoundsMark()) {
                    numStr = ExportConsts.FORMAT_CURRENCY + buildDecimal(ncp2, 0);
                } else {
                    numStr = String.valueOf("0") + buildDecimal(ncp2, 0);
                }
                if (ncp2.getWarningNegative()) {
                    colorStr = "[Red]";
                }
                if (ncp2.getBracketNegative()) {
                    formatStr2 = String.valueOf(numStr) + ";" + colorStr + "(" + numStr + ")";
                } else {
                    formatStr2 = String.valueOf(numStr) + ";" + colorStr + "-" + numStr;
                }
                short formatIndex4 = this.workBook.createDataFormat().getFormat(formatStr2);
                cellStyle2.setDataFormat(formatIndex4);
            } else {
                NumberCellProperty ncp3 = new NumberCellProperty(tempGridCell);
                if (ncp3.getThoundsMark()) {
                    formatStr = ExportConsts.FORMAT_CURRENCY + buildDecimal(ncp3, 0);
                } else {
                    formatStr = String.valueOf("0") + buildDecimal(ncp3, 0);
                }
                short formatIndex5 = this.workBook.createDataFormat().getFormat(String.valueOf(formatStr) + " ");
                cellStyle2.setDataFormat(formatIndex5);
            }
        }
        if (tempGridCell.getDataType() == 3) {
            CurrencyCellProperty curCellProperty = new CurrencyCellProperty(tempGridCell);
            String currencyFormat = makeCurFotmat(curCellProperty);
            short formatIndex6 = this.workBook.createDataFormat().getFormat(currencyFormat);
            cellStyle2.setDataFormat(formatIndex6);
        }
        if (gridCell.getDataType() == 5) {
            short formatIndex7 = this.workBook.createDataFormat().getFormat(ExportConsts.FORMAT_DATE);
            cellStyle2.setDataFormat(formatIndex7);
        }
        gridCell.getDataType();
        this.cellStyleHashMap.put(tempGridCell, cellStyle2);
        return cellStyle2;
    }

    private short transCellAlign(int align, boolean isHorizontal) {
        if (isHorizontal) {
            switch (align) {
                case 0:
                    return (short) 0;
                case 1:
                    return (short) 1;
                case SimpleExportor.EXPORT_MODE_2007_LATER_SUPER /* 2 */:
                    return (short) 3;
                case 3:
                    return (short) 2;
                case 4:
                case 5:
                    return (short) 5;
                case 6:
                    return (short) 3;
                default:
                    return (short) 0;
            }
        }
        switch (align) {
            case 0:
                return (short) 1;
            case 1:
                return (short) 0;
            case SimpleExportor.EXPORT_MODE_2007_LATER_SUPER /* 2 */:
                return (short) 2;
            case 3:
            case 4:
            case 5:
                return (short) 3;
            case 6:
                return (short) 2;
            default:
                return (short) 1;
        }
    }

    private short transBorderStyle(int idx) {
        switch (idx) {
            case 0:
                return (short) 1;
            case 1:
                return (short) 0;
            case SimpleExportor.EXPORT_MODE_2007_LATER_SUPER /* 2 */:
                return (short) 1;
            case 3:
                return (short) 3;
            case 4:
                return (short) 7;
            case 5:
                return (short) 9;
            case 6:
                return (short) 11;
            case 7:
            case 8:
            case 9:
                return (short) 5;
            case 10:
            case 11:
            case ExportConsts.TITLE_HEIGHTINPOINTS /* 12 */:
                return (short) 6;
            case 13:
            case 14:
            case 15:
                return (short) 5;
            default:
                return (short) 1;
        }
    }

    private void mergeCells() {
        GridFieldList fieldList = this.gridData.merges();
        for (int i = 0; i < fieldList.count(); i++) {
            CellField field = fieldList.get(i);
            int rowFrom = field.top - 1;
            int rowTo = field.bottom - 1;
            int colFrom = field.left - 1;
            int colTo = field.right - 1;
            if (this.addTitle) {
                rowFrom++;
                rowTo++;
            }
            int sheetFrom = getSheetIndex(colFrom);
            int sheetTo = getSheetIndex(colTo);
            int j = sheetFrom;
            while (j <= sheetTo) {
                int curColFrom = j == sheetFrom ? colFrom - (j * MAX_COLUMN) : 0;
                int curColTo = j == sheetTo ? colTo - (j * MAX_COLUMN) : MAX_COLUMN;
                getSheet(j).addMergedRegion(new CellRangeAddress(rowFrom, rowTo, curColFrom, curColTo));
                j++;
            }
        }
    }

    private void adjustHW() {
        int colCount = this.gridData.getColCount();
        int rowCount = this.gridData.getRowCount();
        if (this.autoAdjust) {
            for (int col = 0; col < colCount; col++) {
                getSheet(getSheetIndex(col)).autoSizeColumn((short) getCol(col));
            }
            return;
        }
        for (int col2 = 1; col2 < colCount; col2++) {
            int colWidth = this.gridData.getColWidths(col2);
            getSheet(getSheetIndex(col2)).setColumnWidth(getCol(col2) - 1, HSSFHelper.pixelToWidth(colWidth));
        }
        for (int row = 1; row < rowCount; row++) {
            if (this.gridData.getRowVisible(row)) {
                for (int i = 0; i < this.sheets.size(); i++) {
                    int rowHeight = this.gridData.getRowHeights(row);
                    Row hssfRow = this.addTitle ? getSheet(i).getRow(row) : getSheet(i).getRow(row - 1);
                    if (hssfRow != null) {
                        hssfRow.setHeight(HSSFHelper.pixelToHeight(rowHeight));
                    }
                }
            }
        }
    }

    private void hideRowCol() {
        for (int col = 1; col < this.gridData.getColCount(); col++) {
            if (!this.gridData.getColVisible(col)) {
                getSheet(getSheetIndex(col)).setColumnHidden(getCol(col) - 1, true);
            }
        }
        for (int row = 1; row < this.gridData.getRowCount(); row++) {
            if (!this.gridData.getRowVisible(row)) {
                for (int i = 0; i < this.sheets.size(); i++) {
                    Row hssfRow = this.addTitle ? getSheet(i).getRow(row) : getSheet(i).getRow(row - 1);
                    hssfRow.setZeroHeight(true);
                }
            }
        }
    }

    public void setHSSFFontMap(Map hSSFFontMap) {
        this.HSSFFontMap = hSSFFontMap;
    }

    public Map getHSSFFontMap() {
        return this.HSSFFontMap;
    }

    private RichTextString getRichTextString(String title, Workbook wb) {
        HSSFRichTextString hSSFRichTextString = null;
        if (wb instanceof HSSFWorkbook) {
            hSSFRichTextString = new HSSFRichTextString(title);
        } else if (wb instanceof XSSFWorkbook) {
            hSSFRichTextString = new XSSFRichTextString(title);
        } else if (wb instanceof SXSSFWorkbook) {
            hSSFRichTextString = new XSSFRichTextString(title);
        }
        return hSSFRichTextString;
    }
}
